@@ -215,7 +215,7 @@ get_interactions_by_taxa <- function(sourcetaxon, targettaxon = NULL, interactio
   showfield = c("source_taxon_external_id","source_taxon_name","source_taxon_path","source_specimen_life_stage","interaction_type","target_taxon_external_id","target_taxon_name","target_taxon_path","target_specimen_life_stage","latitude","longitude","study_citation","study_external_id","study_source_citation"),
   otherkeys = NULL, bbox = NULL, returnobservations = F, opts = list(), read_csv = read_csv_online){
   if(length(interactiontype)>0){
-    interactiontypes <- as.vector(get_interaction_types()[,1])
+    interactiontypes <- as.vector(get_interaction_types(read_csv = read_csv)[,1])
     if(length(intersect(interactiontypes, interactiontype)) == 0){
       stop ("Unsupported interaction type(s)")
     } else {
